@@ -136,14 +136,14 @@ class OC_Files {
 	* return the content of a file or return a zip file containning multiply files
 	*
 	* @param dir  $dir
-	* @param file $file ; seperated list of files to download
+	* @param file $file array of files
 	* @param boolean $only_header ; boolean to only send header of the request
 	*/
 	public static function get($dir,$files, $only_header = false) {
-		if(strpos($files,';')) {
-			$files=explode(';',$files);
+		if (is_array($files) && count($files) == 1) {
+			$files = $files[0];
 		}
-
+		
 		if(is_array($files)) {
 			self::validateZipDownload($dir,$files);
 			$executionTime = intval(ini_get('max_execution_time'));
@@ -165,7 +165,7 @@ class OC_Files {
 			}
 			$zip->close();
 			set_time_limit($executionTime);
-		}elseif(OC_Filesystem::is_dir($dir.'/'.$files)) {
+		}elseif(OC_Filesystem::is_dir(OC_Files::normalizePath($dir.'/'.$files))) {
 			self::validateZipDownload($dir,$files);
 			$executionTime = intval(ini_get('max_execution_time'));
 			set_time_limit(0);
@@ -184,7 +184,12 @@ class OC_Files {
 		}
 		OC_Util::obEnd();
 		if($zip or OC_Filesystem::is_readable($filename)) {
-			header('Content-Disposition: attachment; filename="'.basename($filename).'"');
+			if ( preg_match( "/MSIE/", $_SERVER["HTTP_USER_AGENT"] ) ) {
+				header( 'Content-Disposition: attachment; filename="' . rawurlencode( basename($filename) ) . '"' );
+			} else {
+				header( 'Content-Disposition: attachment; filename*=UTF-8\'\'' . rawurlencode( basename($filename) )
+													 . '; filename="' . rawurlencode( basename($filename) ) . '"' );
+			}
 			header('Content-Transfer-Encoding: binary');
 			OC_Response::disableCaching();
 			if($zip) {
@@ -193,6 +198,7 @@ class OC_Files {
 				header('Content-Length: ' . filesize($filename));
 			}else{
 				header('Content-Type: '.OC_Filesystem::getMimeType($filename));
+				header("Content-Length: ".OC_Filesystem::filesize($filename));
 			}
 		}elseif($zip or !OC_Filesystem::file_exists($filename)) {
 			header("HTTP/1.0 404 Not Found");
@@ -204,8 +210,6 @@ class OC_Files {
 			die('403 Forbidden');
 		}
 		if($only_header) {
-			if(!$zip)
-				header("Content-Length: ".OC_Filesystem::filesize($filename));
 			return ;
 		}
 		if($zip) {
@@ -341,12 +345,18 @@ class OC_Files {
 		$zipLimit = OC_Config::getValue('maxZipInputSize', OC_Helper::computerFileSize('800 MB'));
 		if($zipLimit > 0) {
 			$totalsize = 0;
-			if(is_array($files)) {
-				foreach($files as $file) {
-					$totalsize += OC_Filesystem::filesize($dir.'/'.$file);
+			if(!is_array($files)) {
+				$files = array($files);
+			}
+			foreach($files as $file) {
+				$path = $dir.'/'.$file;
+				if(OC_Filesystem::is_dir($path)) {
+					foreach(OC_Files::getDirectoryContent($path) as $i) {
+						$totalsize += $i['size'];
+					}
+				} else {
+					$totalsize += OC_Filesystem::filesize($path);
 				}
-			}else{
-				$totalsize += OC_Filesystem::filesize($dir.'/'.$files);
 			}
 			if($totalsize > $zipLimit) {
 				$l = OC_L10N::get('lib');
