@@ -20,6 +20,10 @@ class OC_Filestorage_Local extends OC_Filestorage_Common{
 		return opendir($this->datadir.$path);
 	}
 	public function is_dir($path) {
+		//workaround to detect /Shared as folder, only needed for OC4.5
+		if($path == "files/Shared") {
+			return true;
+		}
 		if(substr($path,-1)=='/') {
 			$path=substr($path,0,-1);
 		}
@@ -29,7 +33,15 @@ class OC_Filestorage_Local extends OC_Filestorage_Common{
 		return is_file($this->datadir.$path);
 	}
 	public function stat($path) {
-		return stat($this->datadir.$path);
+		$fullPath = $this->datadir . $path;
+		$statResult = stat($fullPath);
+
+		if ($statResult['size'] < 0) {
+			$size = self::getFileSizeFromOS($fullPath);
+			$statResult['size'] = $size;
+			$statResult[7] = $size;
+		}
+		return $statResult;
 	}
 	public function filetype($path) {
 		$filetype=filetype($this->datadir.$path);
@@ -42,7 +54,13 @@ class OC_Filestorage_Local extends OC_Filestorage_Common{
 		if($this->is_dir($path)) {
 			return 0;
 		}else{
-			return filesize($this->datadir.$path);
+			$fullPath = $this->datadir . $path;
+			$fileSize = filesize($fullPath);
+			if ($fileSize < 0) {
+				return self::getFileSizeFromOS($fullPath);
+			}
+
+			return $fileSize;
 		}
 	}
 	public function isReadable($path) {
@@ -156,6 +174,34 @@ class OC_Filestorage_Local extends OC_Filestorage_Common{
 		return $return;
 	}
 
+	private static function getFileSizeFromOS($fullPath) {
+		$name = strtolower(php_uname('s'));
+		// Windows OS: we use COM to access the filesystem
+		if (strpos($name, 'win') !== false) {
+			if (class_exists('COM')) {
+				$fsobj = new COM("Scripting.FileSystemObject");
+				$f = $fsobj->GetFile($fullPath);
+				return $f->Size;
+			}
+		} else {
+			if (strpos($name, 'bsd') !== false) {
+				if (\OC_Helper::is_function_enabled('exec')) {
+					return (float)exec('stat -f %z ' . escapeshellarg($fullPath));
+				}
+			} else {
+				if (strpos($name, 'linux') !== false) {
+					if (\OC_Helper::is_function_enabled('exec')) {
+						return (float)exec('stat -c %s ' . escapeshellarg($fullPath));
+					}
+				} else {
+					OC_Log::write('core', 'Unable to determine file size of "' . $fullPath . '". Unknown OS: ' . $name, OC_Log::ERROR);
+				}
+			}
+		}
+
+		return 0;
+	}
+
 	public function hash($path,$type,$raw=false) {
 		return hash_file($type,$this->datadir.$path,$raw);
 	}
@@ -190,6 +236,7 @@ class OC_Filestorage_Local extends OC_Filestorage_Common{
 
 	/**
 	 * check if a file or folder has been updated since $time
+	 * @param string $path
 	 * @param int $time
 	 * @return bool
 	 */
