@@ -7,7 +7,7 @@ OC_JSON::checkAdminUser();
 OCP\JSON::callCheck();
 
 $username = $_POST["username"];
-$group = OC_Util::sanitizeHTML($_POST["group"]);
+$group = $_POST["group"];
 
 // Toggle group
 if(OC_SubAdmin::isSubAdminofGroup($username, $group)) {
@@ -16,4 +16,4 @@ if(OC_SubAdmin::isSubAdminofGroup($username, $group)) {
 	OC_SubAdmin::createSubAdmin($username, $group);
 }
 
-OC_JSON::success();
\ No newline at end of file
+OC_JSON::success();
