@@ -26,7 +26,7 @@ var UserList={
 		UserList.deleteCanceled = false;
 		
 		// Provide user with option to undo
-		$('#notification').html(t('users', 'deleted')+' '+uid+'<span class="undo">'+t('users', 'undo')+'</span>');
+		$('#notification').html(t('settings', 'deleted')+' '+uid+'<span class="undo">'+t('settings', 'undo')+'</span>');
 		$('#notification').data('deleteuser',true);
 		$('#notification').fadeIn();
 	},
@@ -71,17 +71,17 @@ var UserList={
 		var tr = $('tbody tr').first().clone();
 		tr.attr('data-uid', username);
 		tr.find('td.name').text(username);
-		var groupsSelect = $('<select multiple="multiple" class="groupsselect" data-placehoder="Groups" title="Groups"></select>').attr('data-username', username).attr('data-user-groups', groups);
+		var groupsSelect = $('<select multiple="multiple" class="groupsselect" data-placehoder="Groups" title="' + t('settings', 'Groups') + '"></select>').attr('data-username', username).attr('data-user-groups', groups);
 		tr.find('td.groups').empty();
 		if (tr.find('td.subadmins').length > 0) {
-			var subadminSelect = $('<select multiple="multiple" class="subadminsselect" data-placehoder="subadmins" title="' + t('files', 'Group Admin') + '">').attr('data-username', username).attr('data-user-groups', groups).attr('data-subadmin', subadmin);
+			var subadminSelect = $('<select multiple="multiple" class="subadminsselect" data-placehoder="subadmins" title="' + t('settings', 'Group Admin') + '">').attr('data-username', username).attr('data-user-groups', groups).attr('data-subadmin', subadmin);
 			tr.find('td.subadmins').empty();
 		}
 		var allGroups = String($('#content table').attr('data-groups')).split(', ');
 		$.each(allGroups, function(i, group) {
-			groupsSelect.append($('<option value="'+group+'">'+group+'</option>'));
+			groupsSelect.append($('<option value="'+escapeHTML(group)+'">'+escapeHTML(group)+'</option>'));
 			if (typeof subadminSelect !== 'undefined' && group != 'admin') {
-				subadminSelect.append($('<option value="'+group+'">'+group+'</option>'));
+				subadminSelect.append($('<option value="'+escapeHTML(group)+'">'+escapeHTML(group)+'</option>'));
 			}
 		});
 		tr.find('td.groups').append(groupsSelect);
@@ -111,7 +111,7 @@ var UserList={
 			if (quotaSelect.find('option[value="'+quota+'"]').length > 0) {
 				quotaSelect.find('option[value="'+quota+'"]').attr('selected', 'selected');
 			} else {
-				quotaSelect.append('<option value="'+quota+'" selected="selected">'+quota+'</option>');
+				quotaSelect.append('<option value="'+escapeHTML(quota)+'" selected="selected">'+escapeHTML(quota)+'</option>');
 			}
 		}
 		var added = false;
@@ -181,13 +181,13 @@ var UserList={
 			var addGroup = function(group) {
 				$('select[multiple]').each(function(index, element) {
 					if ($(element).find('option[value="'+group +'"]').length == 0) {
-						$(element).append('<option value="'+group+'">'+group+'</option>');
+						$(element).append('<option value="' + escapeHTML(group) + '">' + escapeHTML(group) + '</option>');
 					}
 				})
 			};
 			var label;
 			if(isadmin){
-				label = t('core', 'add group');
+				label = t('settings', 'add group');
 			}else{
 				label = null;
 			}
@@ -221,7 +221,7 @@ var UserList={
 			var addSubAdmin = function(group) {
 				$('select[multiple]').each(function(index, element) {
 					if ($(element).find('option[value="'+group +'"]').length == 0) {
-						$(element).append('<option value="'+group+'">'+group+'</option>');
+						$(element).append('<option value="'+escapeHTML(group)+'">'+escapeHTML(group)+'</option>');
 					}
 				})
 			};
@@ -363,15 +363,21 @@ $(document).ready(function(){
 		var username=$('#newusername').val();
 		var password=$('#newuserpassword').val();
 		if($('#content table tbody tr').filterAttr('data-uid',username).length>0){
-			OC.dialogs.alert('The username is already being used', 'Error creating user');
+			OC.dialogs.alert(
+                t('settings', 'The username is already being used'),
+                t('settings', 'Error creating user'));
 			return;
 		}
 		if($.trim(username) == '') {
-			OC.dialogs.alert('A valid username must be provided', 'Error creating user');
+			OC.dialogs.alert(
+                t('settings', 'A valid username must be provided'),
+                t('settings', 'Error creating user'));
 			return false;
 		}
 		if($.trim(password) == '') {
-			OC.dialogs.alert('A valid password must be provided', 'Error creating user');
+			OC.dialogs.alert(
+                t('settings', 'A valid password must be provided'),
+                t('settings', 'Error creating user'));
 			return false;
 		}
 		var groups=$('#newusergroups').prev().children('div').data('settings').checked;
