@@ -1,21 +1,13 @@
 <?php $TRANSLATIONS = array(
-"email Changed" => "تم تغير العنوان البريدي",
-"Invalid request" => "طلبك غير مفهوم",
 "OpenID Changed" => "تم تغيير ال OpenID",
+"Invalid request" => "طلبك غير مفهوم",
 "Language changed" => "تم تغيير اللغة",
 "__language_name__" => "__language_name__",
-"Log level" => "مستوى المراقبه",
-"Add your application" => "أضف تطبيقاتك",
 "Select an App" => "إختر تطبيقاً",
-"-licensed" => "-مسجل",
-"by" => "من قبل",
 "Ask a question" => "إسأل سؤال",
 "Problems connecting to help database." => "الاتصال بقاعدة بيانات المساعدة لم يتم بنجاح",
 "Go there manually." => "إذهب هنالك بنفسك",
 "Answer" => "الجواب",
-"You use" => "أنت تستخدم",
-"of the available" => "من الموجود",
-"Your password got changed" => "لقد تم تغيير كلمات السر",
 "Unable to change your password" => "لم يتم تعديل كلمة السر بنجاح",
 "Current password" => "كلمات السر الحالية",
 "New password" => "كلمات سر جديدة",
